@@ -25,7 +25,7 @@
 #include <QModelIndexList>
 #include <QMenu>
 
-EntryMenu::EntryMenu(QObject *parent) : QObject(parent), addToStudyAction(QIcon(":/images/icons/flag-blue.png"), tr("Add to &study list"), 0), removeFromStudyAction(QIcon(":/images/icons/flag-black.png"), tr("Remove from &study list"), 0), alreadyKnownAction(QIcon(":/images/icons/flag-green.png"), tr("Already &known"), 0), resetTrainingAction(QIcon(":/images/icons/flag-red.png"), tr("&Reset score"), 0), setTagsAction(QIcon(":/images/icons/tags.png"), tr("Set &tags..."), 0), addTagsAction(QIcon(":/images/icons/tags-add.png"), tr("&Add tags..."), 0), setNotesAction(QIcon(":/images/icons/notes.png"), tr("Edit &notes..."), 0), lastTagsMenu(tr("Recently added tags..."), 0)
+EntryMenu::EntryMenu(QObject *parent) : QObject(parent), copyWritingAction(0), copyReadingAction(0), addToStudyAction(QIcon(":/images/icons/flag-blue.png"), tr("Add to &study list"), 0), removeFromStudyAction(QIcon(":/images/icons/flag-black.png"), tr("Remove from &study list"), 0), alreadyKnownAction(QIcon(":/images/icons/flag-green.png"), tr("Already &known"), 0), resetTrainingAction(QIcon(":/images/icons/flag-red.png"), tr("&Reset score"), 0), setTagsAction(QIcon(":/images/icons/tags.png"), tr("Set &tags..."), 0), addTagsAction(QIcon(":/images/icons/tags-add.png"), tr("&Add tags..."), 0), setNotesAction(QIcon(":/images/icons/notes.png"), tr("Edit &notes..."), 0), lastTagsMenu(tr("Recently added tags..."), 0)
 {
 	lastTagsMenu.setIcon(QIcon(":/images/icons/tags-add.png"));
 	setEnabledAll(false);
@@ -34,6 +34,9 @@ EntryMenu::EntryMenu(QObject *parent) : QObject(parent), addToStudyAction(QIcon(
 
 void EntryMenu::populateMenu(QMenu *menu)
 {
+	menu->addAction(&copyWritingAction);
+	menu->addAction(&copyReadingAction);
+	menu->addSeparator();
 	menu->addAction(&addToStudyAction);
 	menu->addAction(&removeFromStudyAction);
 	menu->addAction(&alreadyKnownAction);
@@ -69,6 +72,8 @@ void EntryMenu::setEnabledAll(bool enabled)
 	addTagsAction.setEnabled(enabled);
 	setNotesAction.setEnabled(enabled);
 	lastTagsMenu.setEnabled(enabled);
+	copyWritingAction.setVisible(false);
+	copyReadingAction.setVisible(false);
 }
 
 void EntryMenu::updateStatus(const QList<ConstEntryPointer>& entries)
@@ -77,12 +82,14 @@ void EntryMenu::updateStatus(const QList<ConstEntryPointer>& entries)
 	bool allMarked = true;
 	bool allUnmarked = true;
 	bool allAlreadyKnown = true;
+	bool hasSelection = entries.size() != 0;
+	bool oneEntry = entries.size() == 1;
+
 	foreach(ConstEntryPointer entry, entries) {
 		if (!entry->trained()) allMarked = false;
 		else allUnmarked = false;
 		if (!entry->alreadyKnown()) allAlreadyKnown = false;
 	}
-	bool hasSelection = entries.size() != 0;
 
 	// Decide which of add to or remove from study action is visible
 	addToStudyAction.setVisible(!allMarked | !hasSelection);
@@ -95,8 +102,30 @@ void EntryMenu::updateStatus(const QList<ConstEntryPointer>& entries)
 	resetTrainingAction.setEnabled(!allUnmarked);
 	setTagsAction.setEnabled(hasSelection);
 	addTagsAction.setEnabled(hasSelection);
-	setNotesAction.setEnabled(entries.size() == 1);
+	setNotesAction.setEnabled(oneEntry);
 	lastTagsMenu.setEnabled(hasSelection && !TagsDialogs::lastAddedTags.isEmpty());
+
+	if (oneEntry) {
+		ConstEntryPointer entry(entries[0]);
+		const QStringList& writings(entry->writings());
+		const QStringList& readings(entry->readings());
+
+		if (!writings.isEmpty()) {
+			copyWritingAction.setVisible(true);
+			copyWritingAction.setText(tr("Copy \"%1\" to clipboard").arg(writings[0]));
+		} else {
+			copyWritingAction.setVisible(false);
+		}
+		if (!readings.isEmpty()) {
+			copyReadingAction.setVisible(true);
+			copyReadingAction.setText(tr("Copy \"%1\" to clipboard").arg(readings[0]));
+		} else {
+			copyReadingAction.setVisible(false);
+		}
+	} else {
+		copyWritingAction.setVisible(false);
+		copyReadingAction.setVisible(false);
+	}
 }
 
 void EntryMenu::updateStatus(const ConstEntryPointer& entry)
