@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2008/2009/2010  Alexandre Courbot
+ *  Copyright (C) 2008-2013  Alexandre Courbot
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -232,7 +232,7 @@ void MainWindow::donationReminderCheck()
 
 void MainWindow::exportUserData()
 {
-	QString to(QFileDialog::getSaveFileName(this, tr("Export user data...")));
+	QString to(QFileDialog::getSaveFileName(this, tr("Export user data..."), "export.dat"));
 	if (to.isEmpty()) return;
 
 	QFile dataFile(Database::instance()->userDBFile());
@@ -273,7 +273,7 @@ void MainWindow::about()
 #error No version defined - the -DVERSION=<version> flag must be set!
 #endif
 	QString message = QString(
-		"<p>Copyright (C) 2008-2012 Alexandre Courbot.</p>"
+		"<p>Copyright (C) 2008-2013 Alexandre Courbot.</p>"
 		"<p align=\"center\"><a href=\"http://www.tagaini.net\">http://www.tagaini.net</a></p><p>This program comes with ABSOLUTELY NO WARRANTY. This is free software, and you are welcome to redistribute it under the conditions of the <a href=\"http://www.gnu.org/licenses/gpl-3.0.html\">GNU General Public License, version 3.0</a>, or (at your option) any later version.</p><hr/>"
 		);
 	QString credits = "<p>Tagaini Jisho uses data from various sources:</p>";
@@ -517,6 +517,11 @@ void MainWindow::focusTextSearch()
 	tWidget->searchField()->lineEdit()->selectAll();
 }
 
+void MainWindow::focusResultsList()
+{
+	searchWidget()->resultsView()->setFocus();
+}
+
 void MainWindow::enableClipboardInput(bool enable)
 {
 	QClipboard *clipboard = QApplication::clipboard();
