@@ -177,7 +177,8 @@ Kanjidic2FilterWidget::Kanjidic2FilterWidget(QWidget *parent) : SearchFilterWidg
 	mainLayout->addWidget(_strokeCountGroupBox);
 	mainLayout->addWidget(componentsGroupBox);
 	mainLayout->addWidget(unicodeGroupBox);
-	mainLayout->addWidget(skipGroupBox);
+	//mainLayout->addWidget(skipGroupBox);
+	skipGroupBox->setVisible(false);
 	mainLayout->addWidget(fourCornerGroupBox);
 	mainLayout->addWidget(gradeGroupBox);
 	mainLayout->setContentsMargins(0, 0, 0, 0);
