@@ -51,6 +51,10 @@ void checkQueryError(const Query &query, const QString &statement)
 	if (query.lastError().isError())
 		qDebug("On query: %s", statement.toUtf8().constData());
 }
+#else
+static void checkQueryError(const Query &query, const QString &statement)
+{
+}
 #endif
 
 bool Query::prepare(const QString &statement)
@@ -62,9 +66,7 @@ bool Query::prepare(const QString &statement)
 	// Busy loop while the shared cache is locked. This is ugly.
 	while ((res = sqlite3_prepare_v2(_connection->_handler, statement.toUtf8().data(), -1, &_stmt, 0)) == SQLITE_LOCKED_SHAREDCACHE){};
 	_lastError = _connection->updateError();
-#ifdef DEBUG_QUERIES
 	checkQueryError(*this, statement);
-#endif
 	if (res != SQLITE_OK) {
 		_state = ERROR;
 		return false;
@@ -86,9 +88,7 @@ bool Query::checkBind(int &col)
 bool Query::checkBindRes()
 {
 	_lastError = _connection->updateError();
-#ifdef DEBUG_QUERIES
 	checkQueryError(*this, queryText());
-#endif
 	if (_lastError.code() != SQLITE_OK) {
 		_state = ERROR;
 		return false;
@@ -161,9 +161,7 @@ void Query::reset()
 	if (!_stmt) return;
 	sqlite3_reset(_stmt);
 	_lastError = _connection->updateError();
-#ifdef DEBUG_QUERIES
 	checkQueryError(*this, queryText());
-#endif
 	_state = PREPARED;
 }
 
@@ -173,9 +171,7 @@ bool Query::exec()
 	// Busy-loop while the shared cache is locked. This is ugly.
 	while (sqlite3_step(_stmt) == SQLITE_LOCKED_SHAREDCACHE){};
 	_lastError = _connection->updateError();
-#ifdef DEBUG_QUERIES
 	checkQueryError(*this, queryText());
-#endif
 	switch (_lastError.code()) {
 	case SQLITE_ROW:
 		_state = FIRSTRES;
@@ -198,9 +194,7 @@ bool Query::next()
 	case RUN:
 		sqlite3_step(_stmt);
 		_lastError = _connection->updateError();
-#ifdef DEBUG_QUERIES
 		checkQueryError(*this, queryText());
-#endif
 		switch (_lastError.code()) {
 		case SQLITE_ROW:
 			return true;
@@ -309,9 +303,7 @@ void Query::clear()
 	if (_stmt) {
 		sqlite3_finalize(_stmt);
 		_lastError = _connection->updateError();
-#ifdef DEBUG_QUERIES
 		checkQueryError(*this, queryText());
-#endif
 		_stmt = 0;
 	}
 	_state = INVALID;
